import { Injectable } from '@nestjs/common';
import { SpaceRepository } from '@app/common/modules/space/repositories';
import { BadRequestException } from '@nestjs/common';

@Injectable()
export class SpacePermissionService {
  constructor(private readonly spaceRepository: SpaceRepository) {}

  async checkUserPermission(
    spaceUuid: string,
    userUuid: string,
    type: string,
  ): Promise<void> {
    try {
      const spaceData = await this.spaceRepository.findOne({
        where: {
          uuid: spaceUuid,
          spaceType: {
            type: type,
          },
          userSpaces: {
            user: {
              uuid: userUuid,
            },
          },
        },
        relations: ['spaceType', 'userSpaces', 'userSpaces.user'],
      });

      if (!spaceData) {
        throw new BadRequestException(
          `You do not have permission to access this ${type}`,
        );
      }
    } catch (err) {
      throw new BadRequestException(err.message || 'Invalid UUID');
    }
  }
}
