import { Column, Entity, ManyToOne, OneToMany, Unique, Index } from 'typeorm';
import { AbstractEntity } from '../../abstract/entities/abstract.entity';
import { DeviceDto } from '../dtos/device.dto';
import { SpaceEntity } from '../../space/entities';
import { ProductEntity } from '../../product/entities';
import { DeviceUserPermissionEntity } from '../../device-user-permission/entities';
import { DeviceNotificationEntity } from '../../device-notification/entities';
import { UserEntity } from '../../user/entities';

@Entity({ name: 'device' })
@Unique(['deviceTuyaUuid'])
export class DeviceEntity extends AbstractEntity<DeviceDto> {
  @Column({
    nullable: false,
  })
  deviceTuyaUuid: string;

  @Column({
    nullable: true,
    default: true,
  })
  isActive: true;

  @ManyToOne(() => UserEntity, (user) => user.userSpaces, { nullable: false })
  user: UserEntity;

  @OneToMany(
    () => DeviceUserPermissionEntity,
    (permission) => permission.device,
    {
      nullable: true,
    },
  )
  permission: DeviceUserPermissionEntity[];
  @OneToMany(
    () => DeviceNotificationEntity,
    (deviceUserNotification) => deviceUserNotification.device,
    {
      nullable: true,
    },
  )
  deviceUserNotification: DeviceNotificationEntity[];

  @ManyToOne(() => SpaceEntity, (space) => space.devicesSpaceEntity, {
    nullable: true,
  })
  spaceDevice: SpaceEntity;

  @ManyToOne(() => ProductEntity, (product) => product.devicesProductEntity, {
    nullable: false,
  })
  productDevice: ProductEntity;

  @Index()
  @Column({ nullable: false })
  uuid: string;

  constructor(partial: Partial<DeviceEntity>) {
    super();
    Object.assign(this, partial);
  }
}
