import { Column, Entity, ManyToOne, Unique } from 'typeorm';
import { UserSpaceDto } from '../dtos';
import { AbstractEntity } from '../../abstract/entities/abstract.entity';
import { SpaceEntity } from '../../space/entities';
import { UserEntity } from '../../user/entities';

@Entity({ name: 'user-space' })
@Unique(['user', 'space'])
export class UserSpaceEntity extends AbstractEntity<UserSpaceDto> {
  @Column({
    type: 'uuid',
    default: () => 'gen_random_uuid()', // Use gen_random_uuid() for default value
    nullable: false,
  })
  public uuid: string;

  @ManyToOne(() => UserEntity, (user) => user.userSpaces, { nullable: false })
  user: UserEntity;

  @ManyToOne(() => SpaceEntity, (space) => space.userSpaces, {
    nullable: false,
  })
  space: SpaceEntity;

  constructor(partial: Partial<UserSpaceEntity>) {
    super();
    Object.assign(this, partial);
  }
}
