import { RegionRepository } from '@app/common/modules/region/repositories';
import { allCountries } from '@app/common/constants/regions';
import { Injectable } from '@nestjs/common';

@Injectable()
export class RegionSeeder {
  constructor(private readonly regionRepository: RegionRepository) {}

  async addRegionDataIfNotFound(): Promise<void> {
    try {
      const existingRegions = await this.regionRepository.find();

      const regionNames = existingRegions.map((region) => region.regionName);

      const missingRegions = allCountries.filter(
        (country) => !regionNames.includes(country),
      );

      if (missingRegions.length > 0) {
        await this.addRegionData(missingRegions);
      }
    } catch (err) {
      console.error('Error while checking region data:', err);
      throw err;
    }
  }

  private async addRegionData(regions: string[]): Promise<void> {
    try {
      const regionEntities = regions.map((regionName) => ({
        regionName,
      }));

      await this.regionRepository.save(regionEntities);
    } catch (err) {
      console.error('Error while adding region data:', err);
      throw err;
    }
  }
}
