import { Injectable } from '@nestjs/common';
import { SpaceType } from '../../constants/space-type.enum';
import { SpaceTypeRepository } from '../../modules/space-type/repositories';

@Injectable()
export class SpaceTypeSeeder {
  constructor(private readonly spaceTypeRepository: SpaceTypeRepository) {}

  async addSpaceTypeDataIfNotFound(): Promise<void> {
    try {
      const existingSpaceTypes = await this.spaceTypeRepository.find();

      const spaceTypeNames = existingSpaceTypes.map((pt) => pt.type);

      const missingSpaceTypes = [];
      if (!spaceTypeNames.includes(SpaceType.COMMUNITY)) {
        missingSpaceTypes.push(SpaceType.COMMUNITY);
      }
      if (!spaceTypeNames.includes(SpaceType.BUILDING)) {
        missingSpaceTypes.push(SpaceType.BUILDING);
      }
      if (!spaceTypeNames.includes(SpaceType.FLOOR)) {
        missingSpaceTypes.push(SpaceType.FLOOR);
      }
      if (!spaceTypeNames.includes(SpaceType.UNIT)) {
        missingSpaceTypes.push(SpaceType.UNIT);
      }
      if (!spaceTypeNames.includes(SpaceType.ROOM)) {
        missingSpaceTypes.push(SpaceType.ROOM);
      }
      if (missingSpaceTypes.length > 0) {
        await this.addSpaceTypeData(missingSpaceTypes);
      }
    } catch (err) {
      console.error('Error while checking space type data:', err);
      throw err;
    }
  }

  private async addSpaceTypeData(spaceTypes: string[]): Promise<void> {
    try {
      const spaceTypeEntities = spaceTypes.map((type) => ({
        type,
      }));

      await this.spaceTypeRepository.save(spaceTypeEntities);
    } catch (err) {
      console.error('Error while adding space type data:', err);
      throw err;
    }
  }
}
