import {
  Body,
  Controller,
  Delete,
  Get,
  HttpException,
  HttpStatus,
  Param,
  Post,
  UseGuards,
} from '@nestjs/common';
import { ApiBearerAuth, ApiTags } from '@nestjs/swagger';
import { DeviceMessagesSubscriptionService } from '../services/device-messages.service';
import { DeviceMessagesAddDto } from '../dtos/device-messages.dto';

import { JwtAuthGuard } from '@app/common/guards/jwt.auth.guard';

@ApiTags('Device Messages Status Module')
@Controller({
  version: '1',
  path: 'device-messages/subscription',
})
export class DeviceMessagesSubscriptionController {
  constructor(
    private readonly deviceMessagesSubscriptionService: DeviceMessagesSubscriptionService,
  ) {}

  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Post()
  async addDeviceMessagesSubscription(
    @Body() deviceMessagesAddDto: DeviceMessagesAddDto,
  ) {
    try {
      const addDetails =
        await this.deviceMessagesSubscriptionService.addDeviceMessagesSubscription(
          deviceMessagesAddDto,
        );
      return {
        statusCode: HttpStatus.CREATED,
        message: 'Device Messages Subscription Added Successfully',
        data: addDetails,
      };
    } catch (error) {
      throw new HttpException(
        error.message || 'Internal server error',
        error.status || HttpStatus.INTERNAL_SERVER_ERROR,
      );
    }
  }

  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Get(':deviceUuid/user/:userUuid')
  async getDeviceMessagesSubscription(
    @Param('deviceUuid') deviceUuid: string,
    @Param('userUuid') userUuid: string,
  ) {
    try {
      const deviceDetails =
        await this.deviceMessagesSubscriptionService.getDeviceMessagesSubscription(
          userUuid,
          deviceUuid,
        );
      return {
        statusCode: HttpStatus.OK,
        message: 'User Device Subscription fetched Successfully',
        data: deviceDetails,
      };
    } catch (error) {
      throw new HttpException(
        error.message || 'Internal server error',
        error.status || HttpStatus.INTERNAL_SERVER_ERROR,
      );
    }
  }
  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Delete()
  async deleteDeviceMessagesSubscription(
    @Body() deviceMessagesAddDto: DeviceMessagesAddDto,
  ) {
    try {
      await this.deviceMessagesSubscriptionService.deleteDeviceMessagesSubscription(
        deviceMessagesAddDto,
      );
      return {
        statusCode: HttpStatus.OK,
        message: 'User subscription deleted Successfully',
      };
    } catch (error) {
      throw new HttpException(
        error.message || 'Internal server error',
        error.status || HttpStatus.INTERNAL_SERVER_ERROR,
      );
    }
  }
}
