import { SpacePermissionService } from '@app/common/helper/services/space.permission.service';
import {
  BadRequestException,
  CanActivate,
  ExecutionContext,
  Injectable,
} from '@nestjs/common';

@Injectable()
export class CommunityPermissionGuard implements CanActivate {
  constructor(private readonly permissionService: SpacePermissionService) {}

  async canActivate(context: ExecutionContext): Promise<boolean> {
    const req = context.switchToHttp().getRequest();

    try {
      const { communityUuid } = req.params;
      const { user } = req;

      if (!communityUuid) {
        throw new BadRequestException('communityUuid is required');
      }

      await this.permissionService.checkUserPermission(
        communityUuid,
        user.uuid,
        'community',
      );

      return true;
    } catch (error) {
      throw error;
    }
  }
}
